//Source file: AppAvailStatusReason.java
//Date: December 2004
//Framework Data Types for 3GPP TS 29.198-03 V6.3.0, Release 6

package org.csapi.jr.se.fw;

/**
 * Defines the reason detailing the change in status of Application availability.
Note 1: 	The client application is unable (or does not wish) to continue using the service instance.
Note 2:	The "expected" recovery time could be defined within the SLA.
 *
 */
public final class AppAvailStatusReason implements java.io.Serializable {

    private int _value;
    private static int _size = 8;
    private static AppAvailStatusReason[] _array = new AppAvailStatusReason[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private AppAvailStatusReason(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined. A permanent failure. See Note 1.
     */
    public static final int _APP_UNAVAILABLE_UNDEFINED =  0;

    /**
     * Undefined. A permanent failure. See Note 1.
     */
    public static final AppAvailStatusReason APP_UNAVAILABLE_UNDEFINED = new AppAvailStatusReason(_APP_UNAVAILABLE_UNDEFINED);

    /**
     * A local failure in the Application has been detected. A permanent failure. See Note 1.
     */
    public static final int _APP_UNAVAILABLE_LOCAL_FAILURE =  1;

    /**
     * A local failure in the Application has been detected. A permanent failure. See Note 1.
     */
    public static final AppAvailStatusReason APP_UNAVAILABLE_LOCAL_FAILURE = new AppAvailStatusReason(_APP_UNAVAILABLE_LOCAL_FAILURE);

    /**
     * A remote failure to the application has been detected, for example a database is not working. A permanent failure. See Note 1.
     */
    public static final int _APP_UNAVAILABLE_REMOTE_FAILURE =  2;

    /**
     * A remote failure to the application has been detected, for example a database is not working. A permanent failure. See Note 1.
     */
    public static final AppAvailStatusReason APP_UNAVAILABLE_REMOTE_FAILURE = new AppAvailStatusReason(_APP_UNAVAILABLE_REMOTE_FAILURE);

    /**
     * The Application is fully overloaded. A temporary problem.  See Note 2.
     */
    public static final int _APP_UNAVAILABLE_OVERLOADED =  3;

    /**
     * The Application is fully overloaded. A temporary problem.  See Note 2.
     */
    public static final AppAvailStatusReason APP_UNAVAILABLE_OVERLOADED = new AppAvailStatusReason(_APP_UNAVAILABLE_OVERLOADED);

    /**
     * The Application has closed itself (for example to protect from fraud or malicious attack) . A permanent failure. See Note 1.
     */
    public static final int _APP_UNAVAILABLE_CLOSED =  4;

    /**
     * The Application has closed itself (for example to protect from fraud or malicious attack) . A permanent failure. See Note 1.
     */
    public static final AppAvailStatusReason APP_UNAVAILABLE_CLOSED = new AppAvailStatusReason(_APP_UNAVAILABLE_CLOSED);

    /**
     * The Framework has detected that the application has failed: for example non-response from an activity test, failure to return heartbeats. A permanent failure. See Note 1.
     */
    public static final int _APP_UNAVAILABLE_NO_RESPONSE =  5;

    /**
     * The Framework has detected that the application has failed: for example non-response from an activity test, failure to return heartbeats. A permanent failure. See Note 1.
     */
    public static final AppAvailStatusReason APP_UNAVAILABLE_NO_RESPONSE = new AppAvailStatusReason(_APP_UNAVAILABLE_NO_RESPONSE);

    /**
     * The Application is unavailable due to SW upgrade or other similar maintenance. A permanent failure. See Note 1.
     */
    public static final int _APP_UNAVAILABLE_SW_UPGRADE =  6;

    /**
     * The Application is unavailable due to SW upgrade or other similar maintenance. A permanent failure. See Note 1.
     */
    public static final AppAvailStatusReason APP_UNAVAILABLE_SW_UPGRADE = new AppAvailStatusReason(_APP_UNAVAILABLE_SW_UPGRADE);

    /**
     * The Application has become available
     */
    public static final int _APP_AVAILABLE =  7;

    /**
     * The Application has become available
     */
    public static final AppAvailStatusReason APP_AVAILABLE = new AppAvailStatusReason(_APP_AVAILABLE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved AppAvailStatusReason object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the AppAvailStatusReason object
     */
    public String getValueText() {
        switch (_value) {
            case _APP_UNAVAILABLE_UNDEFINED:
                return "APP_UNAVAILABLE_UNDEFINED";
            case _APP_UNAVAILABLE_LOCAL_FAILURE:
                return "APP_UNAVAILABLE_LOCAL_FAILURE";
            case _APP_UNAVAILABLE_REMOTE_FAILURE:
                return "APP_UNAVAILABLE_REMOTE_FAILURE";
            case _APP_UNAVAILABLE_OVERLOADED:
                return "APP_UNAVAILABLE_OVERLOADED";
            case _APP_UNAVAILABLE_CLOSED:
                return "APP_UNAVAILABLE_CLOSED";
            case _APP_UNAVAILABLE_NO_RESPONSE:
                return "APP_UNAVAILABLE_NO_RESPONSE";
            case _APP_UNAVAILABLE_SW_UPGRADE:
                return "APP_UNAVAILABLE_SW_UPGRADE";
            case _APP_AVAILABLE:
                return "APP_AVAILABLE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 7
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static AppAvailStatusReason getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof AppAvailStatusReason)) {
            return false;
        }
        AppAvailStatusReason appAvailStatusReason = (AppAvailStatusReason) o; 
        if(!(this.getValue() == appAvailStatusReason.getValue())) {
            return false;
        }
        if (this.hashCode() != appAvailStatusReason.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // AppAvailStatusReason

