//Source file: AuthDomain.java
//Date: December 2004
//Framework Data Types for 3GPP TS 29.198-03 V6.3.0, Release 6

package org.csapi.jr.se.fw;

/**
 * This is Sequence of Data Elements containing all the data necessary to identify a domain: the domain identifier, and a reference to the authentication interface of the domain
 * 
 */
public final class AuthDomain implements java.io.Serializable {

    private org.csapi.jr.se.fw.DomainID domainID;
    private org.csapi.jr.se.CsapiInterface authInterface;

    /**
     * Creates a new AuthDomain instance.
     */
    public AuthDomain () {}

    /**
     * Creates a new AuthDomain instance.
     * @param _domainID   Identifies the domain for authentication. This identifier is assigned to the domain during the initial contractual agreements, and is valid during the lifetime of the contract.
     * @param _authInterface   Identifies the authentication interface of the specific entity. This data element has the same lifetime as the domain authentication process, that is in principle a new interface reference can be provided each time a domain intends to access another. 
     */
    public AuthDomain (org.csapi.jr.se.fw.DomainID _domainID, org.csapi.jr.se.CsapiInterface _authInterface) {

        this.domainID = _domainID;
        this.authInterface = _authInterface;
    }

    /**
     * This method returns a domainID.
     * 
     * @return a org.csapi.jr.se.fw.DomainID value
     */
    public org.csapi.jr.se.fw.DomainID getDomainID() {
        return domainID;
    }

    /**
     * This method returns a authInterface.
     * 
     * @return a org.csapi.jr.se.CsapiInterface value
     */
    public org.csapi.jr.se.CsapiInterface getAuthInterface() {
        return authInterface;
    }


    /**
     * This method sets a domainID.
     */ 
    public void setDomainID(org.csapi.jr.se.fw.DomainID domainID) {
        this.domainID = domainID;
    }

    /**
     * This method sets a authInterface.
     */ 
    public void setAuthInterface(org.csapi.jr.se.CsapiInterface authInterface) {
        this.authInterface = authInterface;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof AuthDomain)) {
            return false;
        } 
        AuthDomain authDomain = (AuthDomain) o;
        if ((this.domainID != null) && (authDomain.domainID != null)) {
            if(!(this.domainID.equals(authDomain.domainID))) {
                return false;
            }
        }
        if ((this.authInterface != null) && (authDomain.authInterface != null)) {
            if(!(this.authInterface.equals(authDomain.authInterface))) {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // AuthDomain

