//Source file: FaultStatisticsError.java
//Date: December 2004
//Framework Data Types for 3GPP TS 29.198-03 V6.3.0, Release 6

package org.csapi.jr.se.fw;

/**
 * Defines the error code associated with a failed attempt to retrieve any fault statistics information. 
 *
 */
public final class FaultStatisticsError implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static FaultStatisticsError[] _array = new FaultStatisticsError[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private FaultStatisticsError(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined error
     */
    public static final int _FAULT_INFO_ERROR_UNDEFINED =  0;

    /**
     * Undefined error
     */
    public static final FaultStatisticsError FAULT_INFO_ERROR_UNDEFINED = new FaultStatisticsError(_FAULT_INFO_ERROR_UNDEFINED);

    /**
     * Fault statistics unavailable
     */
    public static final int _FAULT_INFO_UNAVAILABLE =  1;

    /**
     * Fault statistics unavailable
     */
    public static final FaultStatisticsError FAULT_INFO_UNAVAILABLE = new FaultStatisticsError(_FAULT_INFO_UNAVAILABLE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved FaultStatisticsError object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the FaultStatisticsError object
     */
    public String getValueText() {
        switch (_value) {
            case _FAULT_INFO_ERROR_UNDEFINED:
                return "FAULT_INFO_ERROR_UNDEFINED";
            case _FAULT_INFO_UNAVAILABLE:
                return "FAULT_INFO_UNAVAILABLE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static FaultStatisticsError getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof FaultStatisticsError)) {
            return false;
        }
        FaultStatisticsError faultStatisticsError = (FaultStatisticsError) o; 
        if(!(this.getValue() == faultStatisticsError.getValue())) {
            return false;
        }
        if (this.hashCode() != faultStatisticsError.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // FaultStatisticsError

