//Source file: FwAvailStatusReason.java
//Date: December 2004
//Framework Data Types for 3GPP TS 29.198-03 V6.3.0, Release 6

package org.csapi.jr.se.fw;

/**
 * Defines the reason detailing the change in status of Framework availability.
Note 1: 	The Framework is unable (or does not wish) to continue using the client or service instance.
Note 2:	The 'expected' recovery time could be part of the Framework's local policies.
 *
 */
public final class FwAvailStatusReason implements java.io.Serializable {

    private int _value;
    private static int _size = 8;
    private static FwAvailStatusReason[] _array = new FwAvailStatusReason[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private FwAvailStatusReason(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined. A permanent failure. See Note 1.
     */
    public static final int _FRAMEWORK_UNAVAILABLE_UNDEFINED =  0;

    /**
     * Undefined. A permanent failure. See Note 1.
     */
    public static final FwAvailStatusReason FRAMEWORK_UNAVAILABLE_UNDEFINED = new FwAvailStatusReason(_FRAMEWORK_UNAVAILABLE_UNDEFINED);

    /**
     * A local failure in the Framework has been detected. A permanent failure. See Note 1.
     */
    public static final int _FRAMEWORK_UNAVAILABLE_LOCAL_FAILURE =  1;

    /**
     * A local failure in the Framework has been detected. A permanent failure. See Note 1.
     */
    public static final FwAvailStatusReason FRAMEWORK_UNAVAILABLE_LOCAL_FAILURE = new FwAvailStatusReason(_FRAMEWORK_UNAVAILABLE_LOCAL_FAILURE);

    /**
     * A remote failure to the Framework has been detected, for example a database is not working. A permanent failure. See Note 1.
     */
    public static final int _FRAMEWORK_UNAVAILABLE_REMOTE_FAILURE =  2;

    /**
     * A remote failure to the Framework has been detected, for example a database is not working. A permanent failure. See Note 1.
     */
    public static final FwAvailStatusReason FRAMEWORK_UNAVAILABLE_REMOTE_FAILURE = new FwAvailStatusReason(_FRAMEWORK_UNAVAILABLE_REMOTE_FAILURE);

    /**
     * The Framework is fully overloaded. A temporary problem.  See Note 2.
     */
    public static final int _FRAMEWORK_UNAVAILABLE_OVERLOADED =  3;

    /**
     * The Framework is fully overloaded. A temporary problem.  See Note 2.
     */
    public static final FwAvailStatusReason FRAMEWORK_UNAVAILABLE_OVERLOADED = new FwAvailStatusReason(_FRAMEWORK_UNAVAILABLE_OVERLOADED);

    /**
     * The Framework has closed itself (for example to protect from fraud or malicious attack) . A permanent failure. See Note 1.
     */
    public static final int _FRAMEWORK_UNAVAILABLE_CLOSED =  4;

    /**
     * The Framework has closed itself (for example to protect from fraud or malicious attack) . A permanent failure. See Note 1.
     */
    public static final FwAvailStatusReason FRAMEWORK_UNAVAILABLE_CLOSED = new FwAvailStatusReason(_FRAMEWORK_UNAVAILABLE_CLOSED);

    /**
     * The Framework has detected that the protocol used between client and framework has failed. A permanent failure. See Note 1.
     */
    public static final int _FRAMEWORK_UNAVAILABLE_PROTOCOL_FAILURE =  5;

    /**
     * The Framework has detected that the protocol used between client and framework has failed. A permanent failure. See Note 1.
     */
    public static final FwAvailStatusReason FRAMEWORK_UNAVAILABLE_PROTOCOL_FAILURE = new FwAvailStatusReason(_FRAMEWORK_UNAVAILABLE_PROTOCOL_FAILURE);

    /**
     * The Framework is unavailable due to SW upgrade or other similar maintenance. A permanent failure. See Note 1.
     */
    public static final int _FRAMEWORK_UNAVAILABLE_SW_UPGRADE =  6;

    /**
     * The Framework is unavailable due to SW upgrade or other similar maintenance. A permanent failure. See Note 1.
     */
    public static final FwAvailStatusReason FRAMEWORK_UNAVAILABLE_SW_UPGRADE = new FwAvailStatusReason(_FRAMEWORK_UNAVAILABLE_SW_UPGRADE);

    /**
     * The Framework has become available
     */
    public static final int _FRAMEWORK_AVAILABLE =  7;

    /**
     * The Framework has become available
     */
    public static final FwAvailStatusReason FRAMEWORK_AVAILABLE = new FwAvailStatusReason(_FRAMEWORK_AVAILABLE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved FwAvailStatusReason object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the FwAvailStatusReason object
     */
    public String getValueText() {
        switch (_value) {
            case _FRAMEWORK_UNAVAILABLE_UNDEFINED:
                return "FRAMEWORK_UNAVAILABLE_UNDEFINED";
            case _FRAMEWORK_UNAVAILABLE_LOCAL_FAILURE:
                return "FRAMEWORK_UNAVAILABLE_LOCAL_FAILURE";
            case _FRAMEWORK_UNAVAILABLE_REMOTE_FAILURE:
                return "FRAMEWORK_UNAVAILABLE_REMOTE_FAILURE";
            case _FRAMEWORK_UNAVAILABLE_OVERLOADED:
                return "FRAMEWORK_UNAVAILABLE_OVERLOADED";
            case _FRAMEWORK_UNAVAILABLE_CLOSED:
                return "FRAMEWORK_UNAVAILABLE_CLOSED";
            case _FRAMEWORK_UNAVAILABLE_PROTOCOL_FAILURE:
                return "FRAMEWORK_UNAVAILABLE_PROTOCOL_FAILURE";
            case _FRAMEWORK_UNAVAILABLE_SW_UPGRADE:
                return "FRAMEWORK_UNAVAILABLE_SW_UPGRADE";
            case _FRAMEWORK_AVAILABLE:
                return "FRAMEWORK_AVAILABLE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 7
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static FwAvailStatusReason getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof FwAvailStatusReason)) {
            return false;
        }
        FwAvailStatusReason fwAvailStatusReason = (FwAvailStatusReason) o; 
        if(!(this.getValue() == fwAvailStatusReason.getValue())) {
            return false;
        }
        if (this.hashCode() != fwAvailStatusReason.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // FwAvailStatusReason

