//Source file: FwMigrationServiceAvailableInfo.java
//Date: December 2004
//Framework Data Types for 3GPP TS 29.198-03 V6.3.0, Release 6

package org.csapi.jr.se.fw;

/**
 * Defines the information to be supplied when an SCS becomes available.
 * 
 */
public final class FwMigrationServiceAvailableInfo implements java.io.Serializable {

    private String serviceType;
    private String serviceID;
    private String compatibleServiceID;
    private boolean backwardCompatibilityLevel;
    private boolean migrationRequired;
    private boolean dataMigrated;
    private String migrationDataAndTime;
    private org.csapi.jr.se.fw.MigrationAdditionalInfo[] migrationAdditionalInfo;

    /**
     * Creates a new FwMigrationServiceAvailableInfo instance.
     */
    public FwMigrationServiceAvailableInfo () {}

    /**
     * Creates a new FwMigrationServiceAvailableInfo instance.
     * @param _serviceType   Type of SCS that has become available
     * @param _serviceID   ID of the SCS that has become available
     * @param _compatibleServiceID   ID of the SCS with which this new SCS is compatible with
     * @param _backwardCompatibilityLevel   Specifies if the new SCS is completely backwards compatible with the currently used SCS.Value = TRUE: SCS is completely backwards compatibleValue = FALSE: SCS is not completely backwards compatible. Contact the Framework operator for more information.on how to migrate.
     * @param _migrationRequired   Specifies if the new SCS is replacing the existing SCSValue = TRUE: new SCS is replacing the existing  one - migration is required before the date/time indicated in MigrationDateAndTime fieldValue = FALSE: new SCS is not replacing the existing one, but is provided in addition.All migration to the new SCS, whether required or not, shall involve the application terminating the existing service agreement and signing a new one.
     * @param _dataMigrated   Indicates whether all the data the application set in the previous SCS (for example notifications) is also available in the new SCS.Value = FALSE : the new SCS has not obtained all data (for example notifications) related to the old SCS and the application needs to reset all the previous data.Value = TRUE: the new SCS has obtained data (for example notifications) related to the old SCS, the application can use the new SCS without resetting data.
     * @param _migrationDataAndTime   Indicates the date and time before which applications shall have migrated from existing the existing SCS to this new SCS.Migration to the new SCS requires the application to terminate the existing service agreement, and sign a new one.  Failure to do this by the migration date and time indicated in this field may result in the service agreement being terminated by the Framework, since the service supplier may choose to unregister the service following this date and time.The value of this parameter, if present, shall be ignored if MigrationRequired is set to FALSE
     * @param _migrationAdditionalInfo   Contains additional migration information.  This is initially provided to permit addition of information in later releases without impacting backwards compatibility.
     */
    public FwMigrationServiceAvailableInfo (String _serviceType, String _serviceID, String _compatibleServiceID, boolean _backwardCompatibilityLevel, boolean _migrationRequired, boolean _dataMigrated, String _migrationDataAndTime, org.csapi.jr.se.fw.MigrationAdditionalInfo[] _migrationAdditionalInfo) {

        this.serviceType = _serviceType;
        this.serviceID = _serviceID;
        this.compatibleServiceID = _compatibleServiceID;
        this.backwardCompatibilityLevel = _backwardCompatibilityLevel;
        this.migrationRequired = _migrationRequired;
        this.dataMigrated = _dataMigrated;
        this.migrationDataAndTime = _migrationDataAndTime;
        this.migrationAdditionalInfo = _migrationAdditionalInfo;
    }

    /**
     * This method returns a serviceType.
     * 
     * @return a String value
     */
    public String getServiceType() {
        return serviceType;
    }

    /**
     * This method returns a serviceID.
     * 
     * @return a String value
     */
    public String getServiceID() {
        return serviceID;
    }

    /**
     * This method returns a compatibleServiceID.
     * 
     * @return a String value
     */
    public String getCompatibleServiceID() {
        return compatibleServiceID;
    }

    /**
     * This method returns a backwardCompatibilityLevel.
     * 
     * @return a boolean value
     */
    public boolean getBackwardCompatibilityLevel() {
        return backwardCompatibilityLevel;
    }

    /**
     * This method returns a migrationRequired.
     * 
     * @return a boolean value
     */
    public boolean getMigrationRequired() {
        return migrationRequired;
    }

    /**
     * This method returns a dataMigrated.
     * 
     * @return a boolean value
     */
    public boolean getDataMigrated() {
        return dataMigrated;
    }

    /**
     * This method returns a migrationDataAndTime.
     * 
     * @return a String value
     */
    public String getMigrationDataAndTime() {
        return migrationDataAndTime;
    }

    /**
     * This method returns a migrationAdditionalInfo.
     * 
     * @return a org.csapi.jr.se.fw.MigrationAdditionalInfo[] value
     */
    public org.csapi.jr.se.fw.MigrationAdditionalInfo[] getMigrationAdditionalInfo() {
        return migrationAdditionalInfo;
    }


    /**
     * This method sets a serviceType.
     */ 
    public void setServiceType(String serviceType) {
        this.serviceType = serviceType;
    }

    /**
     * This method sets a serviceID.
     */ 
    public void setServiceID(String serviceID) {
        this.serviceID = serviceID;
    }

    /**
     * This method sets a compatibleServiceID.
     */ 
    public void setCompatibleServiceID(String compatibleServiceID) {
        this.compatibleServiceID = compatibleServiceID;
    }

    /**
     * This method sets a backwardCompatibilityLevel.
     */ 
    public void setBackwardCompatibilityLevel(boolean backwardCompatibilityLevel) {
        this.backwardCompatibilityLevel = backwardCompatibilityLevel;
    }

    /**
     * This method sets a migrationRequired.
     */ 
    public void setMigrationRequired(boolean migrationRequired) {
        this.migrationRequired = migrationRequired;
    }

    /**
     * This method sets a dataMigrated.
     */ 
    public void setDataMigrated(boolean dataMigrated) {
        this.dataMigrated = dataMigrated;
    }

    /**
     * This method sets a migrationDataAndTime.
     */ 
    public void setMigrationDataAndTime(String migrationDataAndTime) {
        this.migrationDataAndTime = migrationDataAndTime;
    }

    /**
     * This method sets a migrationAdditionalInfo.
     */ 
    public void setMigrationAdditionalInfo(org.csapi.jr.se.fw.MigrationAdditionalInfo[] migrationAdditionalInfo) {
        this.migrationAdditionalInfo = migrationAdditionalInfo;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof FwMigrationServiceAvailableInfo)) {
            return false;
        } 
        FwMigrationServiceAvailableInfo fwMigrationServiceAvailableInfo = (FwMigrationServiceAvailableInfo) o;
        if(!(this.serviceType == fwMigrationServiceAvailableInfo.serviceType))  {
            return false;
        }
        if(!(this.serviceID == fwMigrationServiceAvailableInfo.serviceID))  {
            return false;
        }
        if(!(this.compatibleServiceID == fwMigrationServiceAvailableInfo.compatibleServiceID))  {
            return false;
        }
        if(!(this.backwardCompatibilityLevel == fwMigrationServiceAvailableInfo.backwardCompatibilityLevel)) {
            return false;
        }
        if(!(this.migrationRequired == fwMigrationServiceAvailableInfo.migrationRequired)) {
            return false;
        }
        if(!(this.dataMigrated == fwMigrationServiceAvailableInfo.dataMigrated)) {
            return false;
        }
        if(!(this.migrationDataAndTime == fwMigrationServiceAvailableInfo.migrationDataAndTime))  {
            return false;
        }
        if(!(this.migrationAdditionalInfo == fwMigrationServiceAvailableInfo.migrationAdditionalInfo))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // FwMigrationServiceAvailableInfo

