//Source file: FwUnavailReason.java
//Date: December 2004
//Framework Data Types for 3GPP TS 29.198-03 V6.3.0, Release 6

package org.csapi.jr.se.fw;

/**
 * Defines the reason why the Framework is unavailable.
 *
 */
public final class FwUnavailReason implements java.io.Serializable {

    private int _value;
    private static int _size = 6;
    private static FwUnavailReason[] _array = new FwUnavailReason[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private FwUnavailReason(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined
     */
    public static final int _FW_UNAVAILABLE_UNDEFINED =  0;

    /**
     * Undefined
     */
    public static final FwUnavailReason FW_UNAVAILABLE_UNDEFINED = new FwUnavailReason(_FW_UNAVAILABLE_UNDEFINED);

    /**
     * The Local API software or hardware has failed
     */
    public static final int _FW_UNAVAILABLE_LOCAL_FAILURE =  1;

    /**
     * The Local API software or hardware has failed
     */
    public static final FwUnavailReason FW_UNAVAILABLE_LOCAL_FAILURE = new FwUnavailReason(_FW_UNAVAILABLE_LOCAL_FAILURE);

    /**
     * The gateway API software or hardware has failed
     */
    public static final int _FW_UNAVAILABLE_GATEWAY_FAILURE =  2;

    /**
     * The gateway API software or hardware has failed
     */
    public static final FwUnavailReason FW_UNAVAILABLE_GATEWAY_FAILURE = new FwUnavailReason(_FW_UNAVAILABLE_GATEWAY_FAILURE);

    /**
     * The Framework is fully overloaded
     */
    public static final int _FW_UNAVAILABLE_OVERLOADED =  3;

    /**
     * The Framework is fully overloaded
     */
    public static final FwUnavailReason FW_UNAVAILABLE_OVERLOADED = new FwUnavailReason(_FW_UNAVAILABLE_OVERLOADED);

    /**
     * The Framework has closed itself (for example to protect from fraud or malicious attack)
     */
    public static final int _FW_UNAVAILABLE_CLOSED =  4;

    /**
     * The Framework has closed itself (for example to protect from fraud or malicious attack)
     */
    public static final FwUnavailReason FW_UNAVAILABLE_CLOSED = new FwUnavailReason(_FW_UNAVAILABLE_CLOSED);

    /**
     * The protocol used on the client-gateway link has failed
     */
    public static final int _FW_UNAVAILABLE_PROTOCOL_FAILURE =  5;

    /**
     * The protocol used on the client-gateway link has failed
     */
    public static final FwUnavailReason FW_UNAVAILABLE_PROTOCOL_FAILURE = new FwUnavailReason(_FW_UNAVAILABLE_PROTOCOL_FAILURE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved FwUnavailReason object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the FwUnavailReason object
     */
    public String getValueText() {
        switch (_value) {
            case _FW_UNAVAILABLE_UNDEFINED:
                return "FW_UNAVAILABLE_UNDEFINED";
            case _FW_UNAVAILABLE_LOCAL_FAILURE:
                return "FW_UNAVAILABLE_LOCAL_FAILURE";
            case _FW_UNAVAILABLE_GATEWAY_FAILURE:
                return "FW_UNAVAILABLE_GATEWAY_FAILURE";
            case _FW_UNAVAILABLE_OVERLOADED:
                return "FW_UNAVAILABLE_OVERLOADED";
            case _FW_UNAVAILABLE_CLOSED:
                return "FW_UNAVAILABLE_CLOSED";
            case _FW_UNAVAILABLE_PROTOCOL_FAILURE:
                return "FW_UNAVAILABLE_PROTOCOL_FAILURE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 5
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static FwUnavailReason getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof FwUnavailReason)) {
            return false;
        }
        FwUnavailReason fwUnavailReason = (FwUnavailReason) o; 
        if(!(this.getValue() == fwUnavailReason.getValue())) {
            return false;
        }
        if (this.hashCode() != fwUnavailReason.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // FwUnavailReason

