//Source file: LoadStatisticEntityType.java
//Date: December 2004
//Framework Data Types for 3GPP TS 29.198-03 V6.3.0, Release 6

package org.csapi.jr.se.fw;

/**
 * Defines the type of entity (that is service, application or Framework) supplying load statistics.
 *
 */
public final class LoadStatisticEntityType implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static LoadStatisticEntityType[] _array = new LoadStatisticEntityType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private LoadStatisticEntityType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Framework-type load statistics
     */
    public static final int _LOAD_STATISTICS_FW_TYPE =  0;

    /**
     * Framework-type load statistics
     */
    public static final LoadStatisticEntityType LOAD_STATISTICS_FW_TYPE = new LoadStatisticEntityType(_LOAD_STATISTICS_FW_TYPE);

    /**
     * Service-type load statistics
     */
    public static final int _LOAD_STATISTICS_SVC_TYPE =  1;

    /**
     * Service-type load statistics
     */
    public static final LoadStatisticEntityType LOAD_STATISTICS_SVC_TYPE = new LoadStatisticEntityType(_LOAD_STATISTICS_SVC_TYPE);

    /**
     * Application-type load statistics
     */
    public static final int _LOAD_STATISTICS_APP_TYPE =  2;

    /**
     * Application-type load statistics
     */
    public static final LoadStatisticEntityType LOAD_STATISTICS_APP_TYPE = new LoadStatisticEntityType(_LOAD_STATISTICS_APP_TYPE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved LoadStatisticEntityType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the LoadStatisticEntityType object
     */
    public String getValueText() {
        switch (_value) {
            case _LOAD_STATISTICS_FW_TYPE:
                return "LOAD_STATISTICS_FW_TYPE";
            case _LOAD_STATISTICS_SVC_TYPE:
                return "LOAD_STATISTICS_SVC_TYPE";
            case _LOAD_STATISTICS_APP_TYPE:
                return "LOAD_STATISTICS_APP_TYPE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static LoadStatisticEntityType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof LoadStatisticEntityType)) {
            return false;
        }
        LoadStatisticEntityType loadStatisticEntityType = (LoadStatisticEntityType) o; 
        if(!(this.getValue() == loadStatisticEntityType.getValue())) {
            return false;
        }
        if (this.hashCode() != loadStatisticEntityType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // LoadStatisticEntityType

