//Source file: LoadStatisticInfoType.java
//Date: December 2004
//Framework Data Types for 3GPP TS 29.198-03 V6.3.0, Release 6

package org.csapi.jr.se.fw;

/**
 * Defines the type of load statistic information (that is valid or invalid).
 *
 */
public final class LoadStatisticInfoType implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static LoadStatisticInfoType[] _array = new LoadStatisticInfoType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private LoadStatisticInfoType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Valid load statistics
     */
    public static final int _LOAD_STATISTICS_VALID =  0;

    /**
     * Valid load statistics
     */
    public static final LoadStatisticInfoType LOAD_STATISTICS_VALID = new LoadStatisticInfoType(_LOAD_STATISTICS_VALID);

    /**
     * Invalid load statistics
     */
    public static final int _LOAD_STATISTICS_INVALID =  1;

    /**
     * Invalid load statistics
     */
    public static final LoadStatisticInfoType LOAD_STATISTICS_INVALID = new LoadStatisticInfoType(_LOAD_STATISTICS_INVALID);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved LoadStatisticInfoType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the LoadStatisticInfoType object
     */
    public String getValueText() {
        switch (_value) {
            case _LOAD_STATISTICS_VALID:
                return "LOAD_STATISTICS_VALID";
            case _LOAD_STATISTICS_INVALID:
                return "LOAD_STATISTICS_INVALID";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static LoadStatisticInfoType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof LoadStatisticInfoType)) {
            return false;
        }
        LoadStatisticInfoType loadStatisticInfoType = (LoadStatisticInfoType) o; 
        if(!(this.getValue() == loadStatisticInfoType.getValue())) {
            return false;
        }
        if (this.hashCode() != loadStatisticInfoType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // LoadStatisticInfoType

