//Source file: ServiceTypeDescription.java
//Date: December 2004
//Framework Data Types for 3GPP TS 29.198-03 V6.3.0, Release 6

package org.csapi.jr.se.fw;

/**
 * This data type is a Sequence of Data Elements which describes an SCF type. It is a structured data type. It consists of ServiceTypePropertyList, ServiceTypeNameList and AvailableOrUnavailable
 * 
 */
public final class ServiceTypeDescription implements java.io.Serializable {

    private org.csapi.jr.se.fw.ServiceTypeProperty[] serviceTypePropertyList;
    private String[] serviceTypeNameList;
    private boolean availableOrUnavailable;

    /**
     * Creates a new ServiceTypeDescription instance.
     */
    public ServiceTypeDescription () {}

    /**
     * Creates a new ServiceTypeDescription instance.
     * @param _serviceTypePropertyList   A sequence of property name and property mode tuples associated with the SCF type.
     * @param _serviceTypeNameList   The names of the super types of the associated SCF type.
     * @param _availableOrUnavailable   An indication whether the SCF type is available (true) or unavailable (false).
     */
    public ServiceTypeDescription (org.csapi.jr.se.fw.ServiceTypeProperty[] _serviceTypePropertyList, String[] _serviceTypeNameList, boolean _availableOrUnavailable) {

        this.serviceTypePropertyList = _serviceTypePropertyList;
        this.serviceTypeNameList = _serviceTypeNameList;
        this.availableOrUnavailable = _availableOrUnavailable;
    }

    /**
     * This method returns a serviceTypePropertyList.
     * 
     * @return a org.csapi.jr.se.fw.ServiceTypeProperty[] value
     */
    public org.csapi.jr.se.fw.ServiceTypeProperty[] getServiceTypePropertyList() {
        return serviceTypePropertyList;
    }

    /**
     * This method returns a serviceTypeNameList.
     * 
     * @return a String[] value
     */
    public String[] getServiceTypeNameList() {
        return serviceTypeNameList;
    }

    /**
     * This method returns a availableOrUnavailable.
     * 
     * @return a boolean value
     */
    public boolean getAvailableOrUnavailable() {
        return availableOrUnavailable;
    }


    /**
     * This method sets a serviceTypePropertyList.
     */ 
    public void setServiceTypePropertyList(org.csapi.jr.se.fw.ServiceTypeProperty[] serviceTypePropertyList) {
        this.serviceTypePropertyList = serviceTypePropertyList;
    }

    /**
     * This method sets a serviceTypeNameList.
     */ 
    public void setServiceTypeNameList(String[] serviceTypeNameList) {
        this.serviceTypeNameList = serviceTypeNameList;
    }

    /**
     * This method sets a availableOrUnavailable.
     */ 
    public void setAvailableOrUnavailable(boolean availableOrUnavailable) {
        this.availableOrUnavailable = availableOrUnavailable;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof ServiceTypeDescription)) {
            return false;
        } 
        ServiceTypeDescription serviceTypeDescription = (ServiceTypeDescription) o;
        if(!(this.serviceTypePropertyList == serviceTypeDescription.serviceTypePropertyList))  {
            return false;
        }
        if(!(this.serviceTypeNameList == serviceTypeDescription.serviceTypeNameList))  {
            return false;
        }
        if(!(this.availableOrUnavailable == serviceTypeDescription.availableOrUnavailable)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // ServiceTypeDescription

