//Source file: ServiceTypePropertyValue.java
//Date: December 2004
//Framework Data Types for 3GPP TS 29.198-03 V6.3.0, Release 6

package org.csapi.jr.se.fw;

/**
 * This data type is a Sequence of Data Elements which describes a service property associated with a service. It defines the name and mode of the service property, the service property type (for example Boolean, integer), and also value.  It is similar to, but distinct from, TpServiceProperty.  The latter does not define the modes and types and is used to register values for known service properties only.
 * 
 */
public final class ServiceTypePropertyValue implements java.io.Serializable {

    private String servicePropertyName;
    private org.csapi.jr.se.fw.ServiceTypePropertyMode serviceTypePropertyMode;
    private String servicePropertyTypeName;
    private String[] servicePropertyValueList;

    /**
     * Creates a new ServiceTypePropertyValue instance.
     */
    public ServiceTypePropertyValue () {}

    /**
     * Creates a new ServiceTypePropertyValue instance.
     * @param _servicePropertyName   The name of the service property.
     * @param _serviceTypePropertyMode   The mode of the service property.
     * @param _servicePropertyTypeName   The type of the service property.
     * @param _servicePropertyValueList   The Value-list of the service property.
     */
    public ServiceTypePropertyValue (String _servicePropertyName, org.csapi.jr.se.fw.ServiceTypePropertyMode _serviceTypePropertyMode, String _servicePropertyTypeName, String[] _servicePropertyValueList) {

        this.servicePropertyName = _servicePropertyName;
        this.serviceTypePropertyMode = _serviceTypePropertyMode;
        this.servicePropertyTypeName = _servicePropertyTypeName;
        this.servicePropertyValueList = _servicePropertyValueList;
    }

    /**
     * This method returns a servicePropertyName.
     * 
     * @return a String value
     */
    public String getServicePropertyName() {
        return servicePropertyName;
    }

    /**
     * This method returns a serviceTypePropertyMode.
     * 
     * @return a org.csapi.jr.se.fw.ServiceTypePropertyMode value
     */
    public org.csapi.jr.se.fw.ServiceTypePropertyMode getServiceTypePropertyMode() {
        return serviceTypePropertyMode;
    }

    /**
     * This method returns a servicePropertyTypeName.
     * 
     * @return a String value
     */
    public String getServicePropertyTypeName() {
        return servicePropertyTypeName;
    }

    /**
     * This method returns a servicePropertyValueList.
     * 
     * @return a String[] value
     */
    public String[] getServicePropertyValueList() {
        return servicePropertyValueList;
    }


    /**
     * This method sets a servicePropertyName.
     */ 
    public void setServicePropertyName(String servicePropertyName) {
        this.servicePropertyName = servicePropertyName;
    }

    /**
     * This method sets a serviceTypePropertyMode.
     */ 
    public void setServiceTypePropertyMode(org.csapi.jr.se.fw.ServiceTypePropertyMode serviceTypePropertyMode) {
        this.serviceTypePropertyMode = serviceTypePropertyMode;
    }

    /**
     * This method sets a servicePropertyTypeName.
     */ 
    public void setServicePropertyTypeName(String servicePropertyTypeName) {
        this.servicePropertyTypeName = servicePropertyTypeName;
    }

    /**
     * This method sets a servicePropertyValueList.
     */ 
    public void setServicePropertyValueList(String[] servicePropertyValueList) {
        this.servicePropertyValueList = servicePropertyValueList;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof ServiceTypePropertyValue)) {
            return false;
        } 
        ServiceTypePropertyValue serviceTypePropertyValue = (ServiceTypePropertyValue) o;
        if(!(this.servicePropertyName == serviceTypePropertyValue.servicePropertyName))  {
            return false;
        }
        if ((this.serviceTypePropertyMode != null) && (serviceTypePropertyValue.serviceTypePropertyMode != null)) {
            if(!(this.serviceTypePropertyMode.equals(serviceTypePropertyValue.serviceTypePropertyMode))) {
                return false;
            }
        }
        if(!(this.servicePropertyTypeName == serviceTypePropertyValue.servicePropertyTypeName))  {
            return false;
        }
        if(!(this.servicePropertyValueList == serviceTypePropertyValue.servicePropertyValueList))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // ServiceTypePropertyValue

