//Source file: SubjectType.java
//Date: December 2004
//Framework Data Types for 3GPP TS 29.198-03 V6.3.0, Release 6

package org.csapi.jr.se.fw;

/**
 * Defines the subject of a query/notification request/result. 
 *
 */
public final class SubjectType implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static SubjectType[] _array = new SubjectType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private SubjectType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * The subject is neither the framework nor the client application.
     */
    public static final int _SUBJECT_UNDEFINED =  0;

    /**
     * The subject is neither the framework nor the client application.
     */
    public static final SubjectType SUBJECT_UNDEFINED = new SubjectType(_SUBJECT_UNDEFINED);

    /**
     * The subject is the client application.
     */
    public static final int _SUBJECT_CLIENT_APP =  1;

    /**
     * The subject is the client application.
     */
    public static final SubjectType SUBJECT_CLIENT_APP = new SubjectType(_SUBJECT_CLIENT_APP);

    /**
     * The subject is the framework.
     */
    public static final int _SUBJECT_FW =  2;

    /**
     * The subject is the framework.
     */
    public static final SubjectType SUBJECT_FW = new SubjectType(_SUBJECT_FW);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved SubjectType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the SubjectType object
     */
    public String getValueText() {
        switch (_value) {
            case _SUBJECT_UNDEFINED:
                return "SUBJECT_UNDEFINED";
            case _SUBJECT_CLIENT_APP:
                return "SUBJECT_CLIENT_APP";
            case _SUBJECT_FW:
                return "SUBJECT_FW";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static SubjectType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof SubjectType)) {
            return false;
        }
        SubjectType subjectType = (SubjectType) o; 
        if(!(this.getValue() == subjectType.getValue())) {
            return false;
        }
        if (this.hashCode() != subjectType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // SubjectType

