//Source file: SvcUnavailReason.java
//Date: December 2004
//Framework Data Types for 3GPP TS 29.198-03 V6.3.0, Release 6

package org.csapi.jr.se.fw;

/**
 * Defines the reason why a SCF is unavailable.
 *
 */
public final class SvcUnavailReason implements java.io.Serializable {

    private int _value;
    private static int _size = 5;
    private static SvcUnavailReason[] _array = new SvcUnavailReason[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private SvcUnavailReason(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined
     */
    public static final int _SERVICE_UNAVAILABLE_UNDEFINED =  0;

    /**
     * Undefined
     */
    public static final SvcUnavailReason SERVICE_UNAVAILABLE_UNDEFINED = new SvcUnavailReason(_SERVICE_UNAVAILABLE_UNDEFINED);

    /**
     * The Local API software or hardware has failed
     */
    public static final int _SERVICE_UNAVAILABLE_LOCAL_FAILURE =  1;

    /**
     * The Local API software or hardware has failed
     */
    public static final SvcUnavailReason SERVICE_UNAVAILABLE_LOCAL_FAILURE = new SvcUnavailReason(_SERVICE_UNAVAILABLE_LOCAL_FAILURE);

    /**
     * The gateway API software or hardware has failed
     */
    public static final int _SERVICE_UNAVAILABLE_GATEWAY_FAILURE =  2;

    /**
     * The gateway API software or hardware has failed
     */
    public static final SvcUnavailReason SERVICE_UNAVAILABLE_GATEWAY_FAILURE = new SvcUnavailReason(_SERVICE_UNAVAILABLE_GATEWAY_FAILURE);

    /**
     * The SCF is fully overloaded
     */
    public static final int _SERVICE_UNAVAILABLE_OVERLOADED =  3;

    /**
     * The SCF is fully overloaded
     */
    public static final SvcUnavailReason SERVICE_UNAVAILABLE_OVERLOADED = new SvcUnavailReason(_SERVICE_UNAVAILABLE_OVERLOADED);

    /**
     * The SCF has closed itself (for example to protect from fraud or malicious attack)
     */
    public static final int _SERVICE_UNAVAILABLE_CLOSED =  4;

    /**
     * The SCF has closed itself (for example to protect from fraud or malicious attack)
     */
    public static final SvcUnavailReason SERVICE_UNAVAILABLE_CLOSED = new SvcUnavailReason(_SERVICE_UNAVAILABLE_CLOSED);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved SvcUnavailReason object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the SvcUnavailReason object
     */
    public String getValueText() {
        switch (_value) {
            case _SERVICE_UNAVAILABLE_UNDEFINED:
                return "SERVICE_UNAVAILABLE_UNDEFINED";
            case _SERVICE_UNAVAILABLE_LOCAL_FAILURE:
                return "SERVICE_UNAVAILABLE_LOCAL_FAILURE";
            case _SERVICE_UNAVAILABLE_GATEWAY_FAILURE:
                return "SERVICE_UNAVAILABLE_GATEWAY_FAILURE";
            case _SERVICE_UNAVAILABLE_OVERLOADED:
                return "SERVICE_UNAVAILABLE_OVERLOADED";
            case _SERVICE_UNAVAILABLE_CLOSED:
                return "SERVICE_UNAVAILABLE_CLOSED";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 4
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static SvcUnavailReason getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof SvcUnavailReason)) {
            return false;
        }
        SvcUnavailReason svcUnavailReason = (SvcUnavailReason) o; 
        if(!(this.getValue() == svcUnavailReason.getValue())) {
            return false;
        }
        if (this.hashCode() != svcUnavailReason.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // SvcUnavailReason

