//Source file: AppLoadManager.java
//Date: December 2004


package org.csapi.jr.se.fw.fw_application.integrity;

/**
 * The client application developer supplies the load manager application interface to handle requests, reports and other responses from the framework load manager function.  The application supplies the identity of this callback interface at the time it obtains the framework's load manager interface, by use of the obtainInterfaceWithCallback() method on the IpAccess interface.
 *
 */
public interface AppLoadManager extends org.csapi.jr.se.CsapiInterface{

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method queryAppLoadStatsReq shall be used instead, using the new identifier to correlate requests and responses.
The framework uses this method to request the application to provide load statistics records for the application.
     * @param timeInterval Specifies the time interval for which load statistic records should be reported.
     * @deprecated
     */
    void  queryAppLoadReq(org.csapi.jr.se.TimeInterval timeInterval);

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method queryLoadStatsRes shall be used instead, using the new identifier to correlate requests and responses.
The framework uses this method to send load statistic records back to the application that requested the information; that is in response to an invocation of the queryLoadReq method on the IpLoadManager interface.
     * @param loadStatistics Specifies the framework-supplied load statistics
     * @deprecated
     */
    void  queryLoadRes(org.csapi.jr.se.fw.LoadStatistic[] loadStatistics);

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method queryLoadStatsErr shall be used instead, using the new identifier to correlate requests and errors.
The framework uses this method to return an error response to the application that requested the framework's load statistics information, when the framework is unsuccessful in obtaining any load statistic records; that is in response to an invocation of the queryLoadReq method on the IpLoadManager interface.
     * @param loadStatisticsError Specifies the error code associated with the failed attempt to retrieve the framework's load statistics.
     * @deprecated
     */
    void  queryLoadErr(org.csapi.jr.se.fw.LoadStatisticError loadStatisticsError);

    /**
     * Upon detecting load condition change, (for example load level changing from 0 to 1, 0 to 2, 1 to 0, for the SCFs or framework which have been registered for load level notifications) this method is invoked on the application.  In addition this method shall be invoked on the application in order to provide a notification of current load status, when load notifications are first requested, or resumed after suspension.
     * @param loadStatistics Specifies the framework-supplied load statistics, which include the load level change(s).
     */
    void  loadLevelNotification(org.csapi.jr.se.fw.LoadStatistic[] loadStatistics);

    /**
     * The framework uses this method to request the application to resume sending it notifications  for example after a period of suspension during which the framework handled a temporary overload condition.  Upon receipt of this method the client application shall inform the framework of the current load using the reportLoad method on the corresponding IpLoadManager.
     */
    void  resumeNotification();

    /**
     * The framework uses this method to request the application to suspend sending it any notifications  for example while the framework handles a temporary overload condition.
     */
    void  suspendNotification();

    /**
     * The framework uses this method to register to receive notifications of load level changes associated with the application.  Upon receipt of this method the client application shall inform the framework of the current load using the reportLoad method on the corresponding IpLoadManager.
     */
    void  createLoadLevelNotification();

    /**
     * The framework uses this method to unregister for notifications of load level changes associated with the application.
     */
    void  destroyLoadLevelNotification();

    /**
     * The framework uses this method to request the application to provide load statistics records for the application. 
     * @param loadStatsReqID The identifier provided by the framework to correlate the response (when it arrives) with this request.
     * @param timeInterval Specifies the time interval for which load statistic records should be reported.
     */
    void  queryAppLoadStatsReq(int loadStatsReqID, org.csapi.jr.se.TimeInterval timeInterval);

    /**
     * The framework uses this method to send load statistic records back to the application that requested the information; that is in response to an invocation of the queryLoadReq method on the IpLoadManager interface. 
     * @param loadStatsReqID Used by the client application to correlate this response (when it arrives) with the original request.
     * @param loadStatistics Specifies the framework-supplied load statistics.
     */
    void  queryLoadStatsRes(int loadStatsReqID, org.csapi.jr.se.fw.LoadStatistic[] loadStatistics);

    /**
     * The framework uses this method to return an error response to the application that requested the framework's load statistics information, when the framework is unsuccessful in obtaining any load statistic records; that is in response to an invocation of the queryLoadReq method on the IpLoadManager interface.
     * @param loadStatsReqID Used by the client application to correlate this error (when it arrives) with the original request.
     * @param loadStatisticsError Specifies the error code associated with the failed attempt to retrieve the framework's load statistics.
     */
    void  queryLoadStatsErr(int loadStatsReqID, org.csapi.jr.se.fw.LoadStatisticError loadStatisticsError);


} // AppLoadManager

