//Source file: FwLoadManager.java
//Date: December 2004
//Framework to Service Interfaces for 3GPP TS 29.198-03 V6.3.0, Release 6

package org.csapi.jr.se.fw.fw_service.integrity;

/**
 * The framework API should allow the load to be distributed across multiple machines and across multiple component processes, according to a load management policy. The separation of the load management mechanism and load management policy ensures the flexibility of the load management services. The load management policy identifies what load management rules the framework should follow for the specific service. It might specify what action the framework should take as the congestion level changes. For example, some real-time critical applications will want to make sure continuous service is maintained, below a given congestion level, at all costs, whereas other services will be satisfied with disconnecting and trying again later if the congestion level rises. Clearly, the load management policy is related to the QoS level to which the application is subscribed. The framework load management function is represented by the IpFwLoadManager interface.  To handle responses and reports, the service developer must implement the IpSvcLoadManager interface to provide the callback mechanism.																If the IpFwLoadManager interface is implemented by a Framework, at least one of the methods shall be implemented as a minimum requirement. If load level notifications are supported, the createLoadLevelNotification() and destroyLoadLevelNotification() methods shall be implemented.  If suspendNotification() is implemented, then resumeNotification() shall be implemented also.  If a Framework is capable of invoking the IpSvcLoadManager.querySvcLoadStatsReq() method, then it shall implement querySvcLoadStatsRes() and querySvcLoadStatsErr() methods in this interface.
 *
 */
public interface FwLoadManager extends org.csapi.jr.se.CsapiInterface{

    /**
     * The service instance uses this method to report its current load level (0,1, or 2) to the framework  for example when the load level on the service instance has changed. 
At level 0 load, the service instance is performing within its load specifications (that is it is not congested or overloaded). At level 1 load, the service instance is overloaded. At level 2 load, the service instance is severely overloaded.  In addition this method shall be called by the service instance in order to report current load status, when load notifications are first requested, or resumed after suspension.
     * @param loadLevel Specifies the service instance's load level.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  reportLoad(org.csapi.jr.se.fw.LoadLevel loadLevel) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method queryLoadStatsReq shall be used instead, using the new identifier to correlate requests and responses.
The service instance uses this method to request the framework to provide load statistics records for the framework or for the application that uses the service instance. 
     * @param querySubject Specifies the entity (framework or application) for which load statistics records should be reported.
     * @param timeInterval Specifies the time interval for which load statistics records should be reported.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     * @deprecated
     */
    void  queryLoadReq(org.csapi.jr.se.fw.SubjectType querySubject, org.csapi.jr.se.TimeInterval timeInterval) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method querySvcLoadStatsRes shall be used instead, using the new identifier to correlate requests and responses.
The service instance uses this method to send load statistic records back to the framework that requested the information; that is in response to an invocation of the querySvcLoadReq method on the IpSvcLoadManager interface.
     * @param loadStatistics Specifies the service-supplied load statistics.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     * @deprecated
     */
    void  querySvcLoadRes(org.csapi.jr.se.fw.LoadStatistic[] loadStatistics) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method querySvcLoadStatsErr shall be used instead, using the new identifier to correlate requests and errors.
The service instance uses this method to return an error response to the framework that requested the service instance's load statistics information, when the service instance is unsuccessful in obtaining any load statistic records; that is in response to an invocation of the querySvcLoadReq method on the IpSvcLoadManager interface.
     * @param loadStatisticError Specifies the error code associated with the failed attempt to retrieve the service instance's load statistics.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     * @deprecated
     */
    void  querySvcLoadErr(org.csapi.jr.se.fw.LoadStatisticError loadStatisticError) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * The service instance uses this method to register to receive notifications of load level changes associated with the framework or with the application that uses the service instance.  Upon receipt of this method the framework shall inform the service instance of the current framework or application load using the loadLevelNotification method on the corresponding IpSvcLoadManager.
     * @param notificationSubject Specifies the entity (framework or application) for which load level changes should be reported. 
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  createLoadLevelNotification(org.csapi.jr.se.fw.SubjectType notificationSubject) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * The service instance uses this method to unregister for notifications of load level changes associated with the framework or with the application that uses the service instance.
     * @param notificationSubject Specifies the entity (framework or application) for which load level changes should no longer be reported.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  destroyLoadLevelNotification(org.csapi.jr.se.fw.SubjectType notificationSubject) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * The service instance uses this method to request the framework to suspend sending it notifications associated with the framework or with the application that uses the service instance; for example while the service instance handles a temporary overload condition. 
     * @param notificationSubject Specifies the entity (framework or application) for which the sending of notifications by the framework should be suspended. 
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  suspendNotification(org.csapi.jr.se.fw.SubjectType notificationSubject) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * The service instance uses this method to request the framework to resume sending it notifications associated with the framework or with the application that uses the service instance; for example after a period of suspension during which the service instance handled a temporary overload condition.  Upon receipt of this method the framework shall inform the service instance of the current framework or application load using the loadLevelNotification method on the corresponding IpSvcLoadManager.
     * @param notificationSubject Specifies the entity (framework or application) for which the sending of notifications of load level changes by the framework should be resumed.  
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  resumeNotification(org.csapi.jr.se.fw.SubjectType notificationSubject) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * The service instance uses this method to request the framework to provide load statistics records for the framework or for the application that uses the service instance.
     * @param loadStatsReqID The identifier provided by the service instance to correlate the response (when it arrives) with this request.
     * @param querySubject Specifies the entity (framework or application) for which load statistics records should be reported.
     * @param timeInterval Specifies the time interval for which load statistics records should be reported.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  queryLoadStatsReq(int loadStatsReqID, org.csapi.jr.se.fw.SubjectType querySubject, org.csapi.jr.se.TimeInterval timeInterval) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * The service instance uses this method to send load statistic records back to the framework that requested the information; that is in response to an invocation of the querySvcLoadStatsReq method on the IpSvcLoadManager interface. 
     * @param loadStatsReqID Used by the framework to correlate this response (when it arrives) with the original request.
     * @param loadStatistics Specifies the service-supplied load statistics.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  querySvcLoadStatsRes(int loadStatsReqID, org.csapi.jr.se.fw.LoadStatistic[] loadStatistics) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * The service instance uses this method to return an error response to the framework that requested the service instance's load statistics information, when the service instance is unsuccessful in obtaining any load statistic records; that is in response to an invocation of the querySvcLoadStatsReq method on the IpSvcLoadManager interface. 
     * @param loadStatsReqID Used by the framework to correlate this error (when it arrives) with the original request.
     * @param loadStatisticError Specifies the error code associated with the failed attempt to retrieve the service instance's load statistics.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  querySvcLoadStatsErr(int loadStatsReqID, org.csapi.jr.se.fw.LoadStatisticError loadStatisticError) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;


} // FwLoadManager

