//Source file: FwEventNotification.java
//Date: December 2004
//Framework to Service Interfaces for 3GPP TS 29.198-03 V6.3.0, Release 6

package org.csapi.jr.se.fw.fw_service.notification;

/**
 * The event notification mechanism is used to notify the service of generic events that have occurred.  If Event Notifications are supported by a Framework, this interface and the createNotification() and destroyNotification() methods shall be supported.
 *
 */
public interface FwEventNotification extends org.csapi.jr.se.CsapiInterface{

    /**
     * This method is used to install generic notifications so that events can be sent to the service.
     * @return assignmentID    Specifies the ID assigned by the framework for this newly installed event notification.
     * @param eventCriteria Specifies the event specific criteria used by the service to define the event required.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.InvalidEventTypeException     Invalid event type. 
     * @exception org.csapi.jr.se.InvalidCriteriaException     Invalid criteria specified.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    int  createNotification(org.csapi.jr.se.fw.FwEventCriteria eventCriteria) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.InvalidEventTypeException, org.csapi.jr.se.InvalidCriteriaException, org.csapi.jr.se.PlatformException;

    /**
     * This method is used by the service to delete generic notifications from the framework.
     * @param assignmentID Specifies the assignment ID given by the framework when the previous createNotification() was called. If the assignment ID does not correspond to one of the valid assignment IDs, the framework will return the error code P_INVALID_ASSIGNMENT_ID.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.InvalidAssignmentIdException     The assignment ID is invalid
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  destroyNotification(int assignmentID) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.InvalidAssignmentIdException, org.csapi.jr.se.PlatformException;


} // FwEventNotification

