//Source file: ServiceInstanceLifecycleManager.java
//Date: December 2004
//Framework to Service Interfaces for 3GPP TS 29.198-03 V6.3.0, Release 6

package org.csapi.jr.se.fw.fw_service.service_lifecycle;

/**
 * The IpServiceInstanceLifecycleManager interface allows the Framework to create and destroy Service Manager Instances.  This interface and the createServiceManager() and destroyServiceManager() methods shall be implemented by a Service.
 *
 */
public interface ServiceInstanceLifecycleManager extends org.csapi.jr.se.CsapiInterface{

    /**
     * This method returns a new service manager interface reference for the specified application.  The service instance will be configured for the client application using the properties agreed in the service level agreement.
In case there is already a service manager available for the specified application and serviceInstanceID this reference is returned and no new service manager is created.
     * @return serviceManager    Specifies the service manager interface reference for the specified application ID. 
     * @param application Specifies the application for which the service manager interface is requested.
     * @param serviceProperties Specifies the service properties and their values that are to be used to configure the service instance.  These properties form a part of the service level agreement.  An example of these properties is a list of methods that the client application is allowed to invoke on the service interfaces.
     * @param serviceInstanceID Specifies the Service Instance ID that the new Service Manager is to be identified by.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.InvalidPropertyException     The framework does not recognise the property supplied by the client
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    org.csapi.jr.se.Service  createServiceManager(String application, org.csapi.jr.se.fw.ServiceProperty[] serviceProperties, String serviceInstanceID) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.InvalidPropertyException, org.csapi.jr.se.PlatformException;

    /**
     * This method destroys an existing service manager interface reference. This will result in the client application being unable to use the service manager any more. 
     * @param serviceInstance Identifies the Service Instance to be destroyed.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  destroyServiceManager(String serviceInstance) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;


} // ServiceInstanceLifecycleManager

